from matplotlib.patches import Polygon
from numpy import *
from pylab import gca

__author__ = "Jeremy Widman"
__copyright__ = "Copyright 2013, Jeremy Widman"
__credits__ = ["Jeremy Widman", "Yicheng Zhu", "Gavin Huttley"]
__license__ = "GPL"
__version__ = "0.3"
__maintainer__ = "Gavin Huttley"
__email__ = "Gavin.Huttley@anu.edu.au"
__status__ = "Development"


class letter(Polygon):
    """Draws a letter using self.verts."""
    verts = [0, 0]  # empty vertices -- effectively abstract class
    color = None

    def __init__(self, x, y, dx, dy, invert=False, **kwargs):
        """Returns a new letter."""
        if invert:
            self.verts = fabs(self.verts - 100)

        verts = (100. - array(self.verts)) / 100.
        verts *= [dx, dy]
        verts += [x, y]
        Polygon.__init__(self, list(map(tuple, verts)), facecolor=self.color,
                         edgecolor=self.color, **kwargs)


class T(letter):
    """Draws a T"""
    verts = array([[0, 0],
                   [100, 0],
                   [100, 20],
                   [60, 20],
                   [60, 100],
                   [40, 100],
                   [40, 20],
                   [0, 20],
                   [0, 0]])
    color = 'red'


class U(letter):
    verts = array([[0, 0],
                   [18, 0],
                   [18, 62],
                   [20, 68],
                   [22, 72],
                   [25, 76],
                   [29, 79],
                   [32, 81],
                   [37, 82],
                   [41, 83],
                   [50, 84],
                   [59, 83],
                   [63, 82],
                   [68, 81],
                   [71, 79],
                   [75, 76],
                   [78, 72],
                   [80, 68],
                   [82, 62],
                   [82, 0],
                   [100, 0],
                   [100, 64],
                   [98, 75],
                   [96, 80],
                   [92, 85],
                   [88, 89],
                   [83, 92],
                   [80, 94],
                   [76, 96],
                   [60, 99],
                   [50, 100],
                   [35, 99],
                   [24, 96],
                   [20, 94],
                   [17, 92],
                   [12, 89],
                   [8, 85],
                   [4, 80],
                   [2, 75],
                   [0, 64],
                   [0, 0]])
    color = 'red'


class C(letter):

    verts = array([[100, 37],
                   [98, 30],
                   [96, 25],
                   [88, 16],
                   [80, 9],
                   [71, 4],
                   [64, 2],
                   [61, 1],
                   [57, 0],
                   [39, 0],
                   [34, 1],
                   [28, 3],
                   [22, 5],
                   [17, 8],
                   [13, 11],
                   [8, 16],
                   [6, 18],
                   [3, 23],
                   [0, 29],
                   [0, 31],
                   [15, 31],
                   [19, 24],
                   [24, 19],
                   [27, 17],
                   [31, 15],
                   [34, 14],
                   [37, 13],
                   [40, 12],
                   [55, 12],
                   [61, 14],
                   [67, 16],
                   [72, 19],
                   [76, 22],
                   [80, 27],
                   [82, 32],
                   [84, 37],
                   [85, 41],
                   [86, 45],
                   [86, 58],
                   [84, 64],
                   [81, 71],
                   [79, 76],
                   [74, 80],
                   [68, 84],
                   [62, 86],
                   [56, 88],
                   [41, 88],
                   [36, 86],
                   [30, 84],
                   [26, 81],
                   [21, 77],
                   [18, 73],
                   [16, 69],
                   [14, 63],
                   [0, 63],
                   [0, 67],
                   [2, 72],
                   [4, 76],
                   [8, 82],
                   [12, 86],
                   [15, 89],
                   [21, 92],
                   [26, 95],
                   [31, 97],
                   [41, 100],
                   [59, 100],
                   [68, 97],
                   [75, 94],
                   [80, 92],
                   [84, 89],
                   [87, 87],
                   [90, 84],
                   [92, 81],
                   [94, 78],
                   [96, 75],
                   [98, 70],
                   [99, 68],
                   [100, 64],
                   [100, 37]])
    color = 'blue'


class A(letter):
    verts = array([[0, 100],
                   [42, 0],
                   [58, 0],
                   [100, 100],
                   [84, 100],
                   [72, 70],
                   [28, 70],
                   [33, 58],
                   [68, 58],
                   [50, 15],
                   [16, 100],
                   [0, 100]])
    color = 'green'


class G(letter):
    verts = array([[0, 30],
                   [0, 28],
                   [1, 25],
                   [4, 20],
                   [6, 17],
                   [11, 12],
                   [15, 8],
                   [19, 6],
                   [24, 3],
                   [32, 2],
                   [36, 1],
                   [39, 0],
                   [57, 0],
                   [62, 1],
                   [69, 2],
                   [75, 6],
                   [82, 10],
                   [87, 14],
                   [90, 18],
                   [94, 24],
                   [97, 29],
                   [98, 35],
                   [99, 39],
                   [100, 43],
                   [100, 59],
                   [99, 66],
                   [96, 74],
                   [93, 80],
                   [89, 84],
                   [84, 89],
                   [78, 94],
                   [71, 97],
                   [67, 98],
                   [64, 99],
                   [60, 100],
                   [43, 100],
                   [40, 99],
                   [35, 98],
                   [31, 97],
                   [29, 96],
                   [25, 94],
                   [21, 92],
                   [19, 90],
                   [14, 85],
                   [12, 85],
                   [9, 100],
                   [0, 100],
                   [0, 46],
                   [48, 46],
                   [48, 56],
                   [15, 56],
                   [15, 63],
                   [17, 70],
                   [19, 75],
                   [21, 78],
                   [25, 81],
                   [30, 84],
                   [35, 86],
                   [57, 88],
                   [64, 86],
                   [69, 84],
                   [73, 81],
                   [76, 79],
                   [80, 74],
                   [83, 68],
                   [84, 65],
                   [86, 57],
                   [86, 42],
                   [84, 39],
                   [83, 32],
                   [81, 27],
                   [78, 23],
                   [75, 20],
                   [69, 16],
                   [63, 13],
                   [60, 12],
                   [56, 11],
                   [40, 11],
                   [36, 12],
                   [30, 14],
                   [26, 16],
                   [21, 19],
                   [19, 22],
                   [17, 26],
                   [16, 30],
                   [0, 30]])
    color = 'orange'


letter_to_class = {'T': T, 'U': U, 'C': C, 'A': A, 'G': G}


def add_letter(letter, x, y, dx, dy, ax=None, **kwargs):
    """adds t to current axis"""
    if ax is None:
        ax = gca()
    klass = letter_to_class[letter]
    ax.add_artist(klass(x, y, dx, dy, **kwargs))


def set_axis_scale(x, y, ax=None):
    if ax is None:
        ax = gca()
    ax.set_ylim(0, y)
    ax.set_xlim(0, x)
